import { IPropertiesInput, IProvisionOptionals } from "../../../provisioning";
/**
 * Service class which helps to filter or edit input parameters.
 * @export
 * @class ProvisioningService
 */
export declare class ProvisioningService {
    /**
     * Parsers text with properties in key1=val1,key2=val2 format and returns IInputProperty[]
     * @param {string} propertiesText - required runtime property objects passed as a string.
     * @returns {IPropertiesInput[]} array of properties, @see {IPropertiesInput}
     * @memberof ProvisioningService
     */
    static parseProperties(propertiesText: string): IPropertiesInput[];
    /**
     * Reads a YAML file with properties, parses it in key1=val1,key2=val2 format and returns IInputProperty[].
     * @param {string} path - path of the file.
     * @returns {IPropertiesInput[]} array of properties, @see {IPropertiesInput}
     * @memberof ProvisioningService
     */
    static readPropertiesFromYamlFile(path: string): IPropertiesInput[];
    /**
     * Helper method which checks if optional parameters were passed or not.
     * @param {string} properties - required runtime property objects.
     * @param {string} propertiesFile - path of the properties yaml file.
     * @param {string} domainName - name of the domain.
     * @param {string} tenantName - name of the tenant.
     * @param {string} userDataId - ID for the user data specified with user-data.
     * @param {string} userData - user data that is passed into the software services registry.
     * @param {string} accountInfo - account information to use in the JCL JOB statement.
     * @param {string[]} systemNickNames - nicknames of the systems upon which to provision a template.
     * @returns {IProvisionOptionals} object with optional properties, @see {IProvisionOptionals}
     * @memberof ProvisioningService
     */
    static checkForPassedOptionalParms(properties?: string, propertiesFile?: string, domainName?: string, tenantName?: string, userDataId?: string, userData?: string, accountInfo?: string, systemNickNames?: string[]): IProvisionOptionals;
}
