"use strict";
/*
* This program and the accompanying materials are made available under the terms of the *
* Eclipse Public License v2.0 which accompanies this distribution, and is available at *
* https://www.eclipse.org/legal/epl-v20.html                                      *
*                                                                                 *
* SPDX-License-Identifier: EPL-2.0                                                *
*                                                                                 *
* Copyright Contributors to the Zowe Project.                                     *
*                                                                                 *
*/
Object.defineProperty(exports, "__esModule", { value: true });
const vscode = require("vscode");
/**
 * Common implementation of functions and methods associated with the
 * IZoweTreeNode
 *
 * @export
 * @class ZoweDatasetNode
 * @extends {vscode.TreeItem}
 */
class ZoweTreeNode extends vscode.TreeItem {
    /**
     * Creates an instance of ZoweDatasetNode
     *
     * @param {string} label - Displayed in the [TreeView]
     * @param {vscode.TreeItemCollapsibleState} mCollapsibleState - file/folder
     * @param {IZoweTreeNode} mParent
     * @param {Session} session
     * @param {string} etag
     */
    constructor(label, collapsibleState, mParent, session, profile) {
        super(label, collapsibleState);
        this.mParent = mParent;
        this.session = session;
        this.profile = profile;
        this.fullPath = "";
        this.dirty = false;
        this.children = [];
        this.binaryFiles = {};
        this.binary = false;
        this.shortLabel = "";
        // TODO Check this
        if (!profile && mParent && mParent.getProfile()) {
            this.profile = mParent.getProfile();
        }
    }
    /**
     * Retrieves parent node of this IZoweTreeNode
     *
     * @returns {Promise<IZoweTreeNode>}
     */
    getParent() {
        return this.mParent;
    }
    /**
     * Returns the [Session] for this node
     *
     * @returns {Session}
     */
    getSession() {
        return this.session || (this.getParent() ? this.getParent().getSession() : undefined);
    }
    /**
     * Returns the IProfileLoaded profile for this node
     *
     * @returns {IProfileLoaded}
     */
    getProfile() {
        return (this.profile) ? this.profile : this.getParent() ? this.getParent().getProfile() : undefined;
    }
    /**
     * Implements access to profile name
     *
     * @returns {string}
     */
    getProfileName() {
        if (this.profile) {
            return this.profile.name;
        }
        return undefined;
    }
    /**
     * This is the default was that the label should be accessed as it
     * automatically trims the value
     */
    getLabel() {
        return this.label.trim();
    }
    /**
     * Sets the IProfileLoaded profile for this node.
     * Only used by ZoweTreeNode and should be refactored out
     *
     * @param {IProfileLoaded}
     */
    setProfile(aProfile) {
        this.profile = aProfile;
    }
}
exports.ZoweTreeNode = ZoweTreeNode;

//# sourceMappingURL=ZoweTreeNode.js.map
