"use strict";
/*
* This program and the accompanying materials are made available under the terms of the *
* Eclipse Public License v2.0 which accompanies this distribution, and is available at *
* https://www.eclipse.org/legal/epl-v20.html                                      *
*                                                                                 *
* SPDX-License-Identifier: EPL-2.0                                                *
*                                                                                 *
* Copyright Contributors to the Zowe Project.                                     *
*                                                                                 *
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const vscode_1 = require("vscode");
const extension = require("../src/extension");
const nls = require("vscode-nls");
const localize = nls.config({ messageFormat: nls.MessageFormat.file })(__filename);
/*
 * Created this file to be a place where commonly used functions will be defined.
 * I noticed we have a lot of repetition of some common
 * functionality in many places.
 */
function applyIcons(node, state) {
    let light;
    let dark;
    if ([extension.DS_PDS_CONTEXT, extension.DS_PDS_CONTEXT + extension.FAV_SUFFIX,
        extension.USS_DIR_CONTEXT,
        extension.USS_DIR_CONTEXT + extension.FAV_SUFFIX,
        extension.JOBS_JOB_CONTEXT,
        extension.JOBS_JOB_CONTEXT + extension.FAV_SUFFIX].includes(node.contextValue)) {
        if (state === extension.ICON_STATE_OPEN) {
            light = path.join(__dirname, "..", "..", "resources", "light", "folder-open.svg");
            dark = path.join(__dirname, "..", "..", "resources", "dark", "folder-open.svg");
        }
        else {
            light = path.join(__dirname, "..", "..", "resources", "light", "folder-closed.svg");
            dark = path.join(__dirname, "..", "..", "resources", "dark", "folder-closed.svg");
        }
    }
    else if ([extension.FAVORITE_CONTEXT].includes(node.contextValue)) {
        if (state === extension.ICON_STATE_OPEN) {
            light = path.join(__dirname, "..", "..", "resources", "light", "folder-root-favorite-open.svg");
            dark = path.join(__dirname, "..", "..", "resources", "dark", "folder-root-favorite-open.svg");
        }
        else {
            light = path.join(__dirname, "..", "..", "resources", "light", "folder-root-favorite-closed.svg");
            dark = path.join(__dirname, "..", "..", "resources", "dark", "folder-root-favorite-closed.svg");
        }
    }
    else if ([extension.DS_SESSION_CONTEXT, extension.USS_SESSION_CONTEXT,
        extension.JOBS_SESSION_CONTEXT].includes(node.contextValue)) {
        if (state === extension.ICON_STATE_OPEN) {
            light = path.join(__dirname, "..", "..", "resources", "light", "folder-root-default-open.svg");
            dark = path.join(__dirname, "..", "..", "resources", "dark", "folder-root-default-open.svg");
        }
        else {
            light = path.join(__dirname, "..", "..", "resources", "light", "folder-root-default-closed.svg");
            dark = path.join(__dirname, "..", "..", "resources", "dark", "folder-root-default-closed.svg");
        }
    }
    else if ([extension.DS_SESSION_CONTEXT + extension.FAV_SUFFIX,
        extension.JOBS_SESSION_CONTEXT + extension.FAV_SUFFIX,
        extension.USS_SESSION_CONTEXT + extension.FAV_SUFFIX].includes(node.contextValue)) {
        light = path.join(__dirname, "..", "..", "resources", "light", "pattern.svg");
        dark = path.join(__dirname, "..", "..", "resources", "dark", "pattern.svg");
    }
    else if ([extension.DS_DS_CONTEXT,
        extension.DS_DS_CONTEXT + extension.FAV_SUFFIX,
        extension.DS_MEMBER_CONTEXT, extension.DS_TEXT_FILE_CONTEXT,
        extension.DS_TEXT_FILE_CONTEXT + extension.FAV_SUFFIX,
        extension.JOBS_SPOOL_CONTEXT].includes(node.contextValue)) {
        light = path.join(__dirname, "..", "..", "resources", "light", "document.svg");
        dark = path.join(__dirname, "..", "..", "resources", "dark", "document.svg");
    }
    else if ([extension.DS_MIGRATED_FILE_CONTEXT,
        extension.DS_MIGRATED_FILE_CONTEXT + extension.FAV_SUFFIX].includes(node.contextValue)) {
        light = path.join(__dirname, "..", "..", "resources", "dark", "document.svg");
        dark = path.join(__dirname, "..", "..", "resources", "light", "document.svg");
    }
    else if ([extension.DS_BINARY_FILE_CONTEXT,
        extension.DS_BINARY_FILE_CONTEXT + extension.FAV_SUFFIX].includes(node.contextValue)) {
        light = path.join(__dirname, "..", "..", "resources", "light", "document.svg");
        dark = path.join(__dirname, "..", "..", "resources", "dark", "document.svg");
    }
    else {
        return undefined;
    }
    node.iconPath = { light, dark };
    return { light, dark };
}
exports.applyIcons = applyIcons;
function sortTreeItems(favorites, specificContext) {
    favorites.sort((a, b) => {
        if (a.contextValue === specificContext) {
            if (b.contextValue === specificContext) {
                return a.label.toUpperCase() > b.label.toUpperCase() ? 1 : -1;
            }
            else {
                return -1;
            }
        }
        else if (b.contextValue === specificContext) {
            return 1;
        }
        return a.label.toUpperCase() > b.label.toUpperCase() ? 1 : -1;
    });
}
exports.sortTreeItems = sortTreeItems;
/**
 * For no obvious reason a label change is often required to make a node repaint.
 * This function does this by adding or removing a blank.
 * @param {TreeItem} node - the node element
 */
function labelHack(node) {
    node.label = node.label.endsWith(" ") ? node.label.substring(0, node.label.length - 1) : node.label + " ";
}
exports.labelHack = labelHack;
function resolveQuickPickHelper(quickpick) {
    return __awaiter(this, void 0, void 0, function* () {
        return new Promise((c) => quickpick.onDidAccept(() => c(quickpick.activeItems[0])));
    });
}
exports.resolveQuickPickHelper = resolveQuickPickHelper;
// tslint:disable-next-line: max-classes-per-file
class FilterItem {
    constructor(text) {
        this.text = text;
    }
    get label() { return this.text; }
    get description() { return ""; }
    get alwaysShow() { return false; }
}
exports.FilterItem = FilterItem;
// tslint:disable-next-line: max-classes-per-file
class FilterDescriptor {
    constructor(text) {
        this.text = text;
    }
    get label() { return this.text; }
    get description() { return ""; }
    get alwaysShow() { return true; }
}
exports.FilterDescriptor = FilterDescriptor;
// tslint:disable-next-line: max-classes-per-file
class OwnerFilterDescriptor extends FilterDescriptor {
    constructor() {
        super("\uFF0B " + localize(0, null));
    }
}
exports.OwnerFilterDescriptor = OwnerFilterDescriptor;
// tslint:disable-next-line: max-classes-per-file
class JobIdFilterDescriptor extends FilterDescriptor {
    constructor() {
        super("\uFF0B " + localize(1, null));
    }
}
exports.JobIdFilterDescriptor = JobIdFilterDescriptor;
/*************************************************************************************************************
 * Returns array of all subnodes of given node
 *************************************************************************************************************/
function concatChildNodes(nodes) {
    let allNodes = new Array();
    for (const node of nodes) {
        allNodes = allNodes.concat(concatChildNodes(node.children));
        allNodes.push(node);
    }
    return allNodes;
}
exports.concatChildNodes = concatChildNodes;
/*************************************************************************************************************
 * Determine IDE name to display based on app environment
 *************************************************************************************************************/
function getAppName(isTheia) {
    return isTheia ? "Theia" : "VS Code";
}
exports.getAppName = getAppName;
/*************************************************************************************************************
 * Error Hanndling
 * @param {errorDetails} error.mDetails
 * @param {label} - additional information such as profile name, credentials, messageID etc
 * @param {moreInfo} - additional/customized error messages
 *************************************************************************************************************/
function errorHandling(errorDetails, label, moreInfo) {
    let httpErrCode = null;
    if (errorDetails.mDetails !== undefined) {
        httpErrCode = errorDetails.mDetails.errorCode;
    }
    switch (httpErrCode) {
        // tslint:disable-next-line: no-magic-numbers
        case 401: {
            vscode_1.window.showErrorMessage(localize(2, null) +
                localize(3, null) +
                `\n${label}\n` +
                localize(4, null));
            break;
        }
        default: {
            vscode_1.window.showErrorMessage(moreInfo);
            break;
        }
    }
    return;
}
exports.errorHandling = errorHandling;

//# sourceMappingURL=utils.js.map
