"use strict";
/*
* This program and the accompanying materials are made available under the terms of the *
* Eclipse Public License v2.0 which accompanies this distribution, and is available at *
* https://www.eclipse.org/legal/epl-v20.html                                      *
*                                                                                 *
* SPDX-License-Identifier: EPL-2.0                                                *
*                                                                                 *
* Copyright Contributors to the Zowe Project.                                     *
*                                                                                 *
*/
Object.defineProperty(exports, "__esModule", { value: true });
const vscode = require("vscode");
let wasSavedRecently = false;
let saveListener = null;
/**
 * Helper function which sets up listener for save wiping out the data after certain delay to prevent the fact of second save
 * @param wipeOutTime {number}
 */
function attachRecentSaveListener(wipeOutTime = 500) {
    if (saveListener) {
        saveListener.dispose();
    }
    saveListener = vscode.workspace.onDidSaveTextDocument(() => {
        wasSavedRecently = true;
        setTimeout(() => {
            wasSavedRecently = false;
        }, wipeOutTime);
    });
}
exports.attachRecentSaveListener = attachRecentSaveListener;
/**
 * Helper function which returns saved save flag
 *
 * @returns {boolean}
 */
function getRecentSaveStatus() {
    return wasSavedRecently;
}
exports.getRecentSaveStatus = getRecentSaveStatus;
/**
 * Helper function which disposes recent save listener
 */
function disposeRecentSaveListener() {
    if (saveListener) {
        saveListener.dispose();
    }
}
exports.disposeRecentSaveListener = disposeRecentSaveListener;

//# sourceMappingURL=file.js.map
